# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lane.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ..model import model_pb2 as model__pb2
from ..traffic_manage import routing_pb2 as routing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nlane.proto\x12\x02v1\x1a\x19google/protobuf/any.proto\x1a\x0bmodel.proto\x1a\rrouting.proto\"D\n\x0cTrafficEntry\x12\x0c\n\x04type\x18\x01 \x01(\t\x12&\n\x08selector\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xb4\x01\n\x16ServiceGatewaySelector\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x36\n\x06labels\x18\x03 \x03(\x0b\x32&.v1.ServiceGatewaySelector.LabelsEntry\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xa6\x01\n\x0fServiceSelector\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12/\n\x06labels\x18\x03 \x03(\x0b\x32\x1f.v1.ServiceSelector.LabelsEntry\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xb6\x02\n\tLaneGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x10.v1.TrafficEntry\x12*\n\x0c\x64\x65stinations\x18\x04 \x03(\x0b\x32\x14.v1.DestinationGroup\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\x1b\n\x05rules\x18\x0b \x03(\x0b\x32\x0c.v1.LaneRule\x12-\n\x08metadata\x18\x14 \x03(\x0b\x32\x1b.v1.LaneGroup.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x10TrafficMatchRule\x12\"\n\targuments\x18\x04 \x03(\x0b\x32\x0f.v1.SourceMatch\x12\x38\n\tmatchMode\x18\x0e \x01(\x0e\x32%.v1.TrafficMatchRule.TrafficMatchMode\"#\n\x10TrafficMatchMode\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\"\xda\x02\n\x08LaneRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12\x30\n\x12traffic_match_rule\x18\x04 \x01(\x0b\x32\x14.v1.TrafficMatchRule\x12\x1b\n\x13\x64\x65\x66\x61ult_label_value\x18\x05 \x01(\t\x12\x0e\n\x06\x65nable\x18\x06 \x01(\x08\x12.\n\nmatch_mode\x18\x07 \x01(\x0e\x32\x1a.v1.LaneRule.LaneMatchMode\x12\x10\n\x08revision\x18\x08 \x01(\t\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\r\n\x05\x65time\x18\x0b \x01(\t\x12\x10\n\x08priority\x18\x0c \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\"+\n\rLaneMatchMode\x12\n\n\x06STRICT\x10\x00\x12\x0e\n\nPERMISSIVE\x10\x01\x42\x8a\x01\n7com.tencent.polaris.specification.api.v1.traffic.manageB\tLaneProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.traffic.manageB\tLaneProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manage'
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._loaded_options = None
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICESELECTOR_LABELSENTRY']._loaded_options = None
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LANEGROUP_METADATAENTRY']._loaded_options = None
  _globals['_LANEGROUP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TRAFFICENTRY']._serialized_start=73
  _globals['_TRAFFICENTRY']._serialized_end=141
  _globals['_SERVICEGATEWAYSELECTOR']._serialized_start=144
  _globals['_SERVICEGATEWAYSELECTOR']._serialized_end=324
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_start=262
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_end=324
  _globals['_SERVICESELECTOR']._serialized_start=327
  _globals['_SERVICESELECTOR']._serialized_end=493
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_start=262
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_end=324
  _globals['_LANEGROUP']._serialized_start=496
  _globals['_LANEGROUP']._serialized_end=806
  _globals['_LANEGROUP_METADATAENTRY']._serialized_start=759
  _globals['_LANEGROUP_METADATAENTRY']._serialized_end=806
  _globals['_TRAFFICMATCHRULE']._serialized_start=809
  _globals['_TRAFFICMATCHRULE']._serialized_end=958
  _globals['_TRAFFICMATCHRULE_TRAFFICMATCHMODE']._serialized_start=923
  _globals['_TRAFFICMATCHRULE_TRAFFICMATCHMODE']._serialized_end=958
  _globals['_LANERULE']._serialized_start=961
  _globals['_LANERULE']._serialized_end=1307
  _globals['_LANERULE_LANEMATCHMODE']._serialized_start=1264
  _globals['_LANERULE_LANEMATCHMODE']._serialized_end=1307
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from ..model import model_pb2 as _model_pb2
from ..traffic_manage import routing_pb2 as _routing_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficEntry(_message.Message):
    __slots__ = ("type", "selector")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    type: str
    selector: _any_pb2.Any
    def __init__(self, type: _Optional[str] = ..., selector: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ServiceGatewaySelector(_message.Message):
    __slots__ = ("namespace", "service", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    service: str
    labels: _containers.MessageMap[str, _model_pb2.MatchString]
    def __init__(self, namespace: _Optional[str] = ..., service: _Optional[str] = ..., labels: _Optional[_Mapping[str, _model_pb2.MatchString]] = ...) -> None: ...

class ServiceSelector(_message.Message):
    __slots__ = ("namespace", "service", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _model_pb2.MatchString
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_model_pb2.MatchString, _Mapping]] = ...) -> None: ...
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    service: str
    labels: _containers.MessageMap[str, _model_pb2.MatchString]
    def __init__(self, namespace: _Optional[str] = ..., service: _Optional[str] = ..., labels: _Optional[_Mapping[str, _model_pb2.MatchString]] = ...) -> None: ...

class LaneGroup(_message.Message):
    __slots__ = ("id", "name", "entries", "destinations", "revision", "description", "ctime", "mtime", "rules", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    RULES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    entries: _containers.RepeatedCompositeFieldContainer[TrafficEntry]
    destinations: _containers.RepeatedCompositeFieldContainer[_routing_pb2.DestinationGroup]
    revision: str
    description: str
    ctime: str
    mtime: str
    rules: _containers.RepeatedCompositeFieldContainer[LaneRule]
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., entries: _Optional[_Iterable[_Union[TrafficEntry, _Mapping]]] = ..., destinations: _Optional[_Iterable[_Union[_routing_pb2.DestinationGroup, _Mapping]]] = ..., revision: _Optional[str] = ..., description: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., rules: _Optional[_Iterable[_Union[LaneRule, _Mapping]]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class TrafficMatchRule(_message.Message):
    __slots__ = ("arguments", "matchMode")
    class TrafficMatchMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        AND: _ClassVar[TrafficMatchRule.TrafficMatchMode]
        OR: _ClassVar[TrafficMatchRule.TrafficMatchMode]
    AND: TrafficMatchRule.TrafficMatchMode
    OR: TrafficMatchRule.TrafficMatchMode
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    MATCHMODE_FIELD_NUMBER: _ClassVar[int]
    arguments: _containers.RepeatedCompositeFieldContainer[_routing_pb2.SourceMatch]
    matchMode: TrafficMatchRule.TrafficMatchMode
    def __init__(self, arguments: _Optional[_Iterable[_Union[_routing_pb2.SourceMatch, _Mapping]]] = ..., matchMode: _Optional[_Union[TrafficMatchRule.TrafficMatchMode, str]] = ...) -> None: ...

class LaneRule(_message.Message):
    __slots__ = ("id", "name", "group_name", "traffic_match_rule", "default_label_value", "enable", "match_mode", "revision", "ctime", "mtime", "etime", "priority", "description")
    class LaneMatchMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STRICT: _ClassVar[LaneRule.LaneMatchMode]
        PERMISSIVE: _ClassVar[LaneRule.LaneMatchMode]
    STRICT: LaneRule.LaneMatchMode
    PERMISSIVE: LaneRule.LaneMatchMode
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    TRAFFIC_MATCH_RULE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LABEL_VALUE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    MATCH_MODE_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    MTIME_FIELD_NUMBER: _ClassVar[int]
    ETIME_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    group_name: str
    traffic_match_rule: TrafficMatchRule
    default_label_value: str
    enable: bool
    match_mode: LaneRule.LaneMatchMode
    revision: str
    ctime: str
    mtime: str
    etime: str
    priority: int
    description: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., group_name: _Optional[str] = ..., traffic_match_rule: _Optional[_Union[TrafficMatchRule, _Mapping]] = ..., default_label_value: _Optional[str] = ..., enable: bool = ..., match_mode: _Optional[_Union[LaneRule.LaneMatchMode, str]] = ..., revision: _Optional[str] = ..., ctime: _Optional[str] = ..., mtime: _Optional[str] = ..., etime: _Optional[str] = ..., priority: _Optional[int] = ..., description: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xf7\x01\n\x0cLoginRequest\x12+\n\x05owner\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x07options\x18\x04 \x03(\x0b\x32\x1d.v1.LoginRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe7\x02\n\rLoginResponse\x12\x36\n\x07user_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07user_id\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04role\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x08owner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08owner_id\x12+\n\x05token\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\x07options\x18\x06 \x03(\x0b\x32\x1e.v1.LoginResponse.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x05\n\x04User\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06source\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tuser_type\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tuser_type\x12,\n\x06mobile\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x65mail\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12(\n\x08metadata\x18\x0e \x03(\x0b\x32\x16.v1.User.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x12ModifyUserPassword\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0cold_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cold_password\x12@\n\x0cnew_password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cnew_password\"f\n\x11UserGroupRelation\x12\x38\n\x08group_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08group_id\x12\x17\n\x05users\x18\x02 \x03(\x0b\x32\x08.v1.User\"\x8a\x05\n\tUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x08relation\x18\t \x01(\x0b\x32\x15.v1.UserGroupRelation\x12<\n\nuser_count\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nuser_count\x12,\n\x06source\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x08metadata\x18\x0c \x03(\x0b\x32\x1b.v1.UserGroup.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x04\n\x0fModifyUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\radd_relations\x18\x07 \x01(\x0b\x32\x15.v1.UserGroupRelationR\radd_relations\x12\x41\n\x10remove_relations\x18\x08 \x01(\x0b\x32\x15.v1.UserGroupRelationR\x10remove_relations\x12\x33\n\x08metadata\x18\t \x03(\x0b\x32!.v1.ModifyUserGroup.MetadataEntry\x12,\n\x06source\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x02\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\x12\"\n\x0c\x64\x65\x66\x61ult_role\x18\x06 \x01(\x08R\x0c\x64\x65\x66\x61ult_role\x12(\n\x08metadata\x18\x07 \x03(\x0b\x32\x16.v1.Role.MetadataEntry\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\x17\n\x05users\x18\x14 \x03(\x0b\x32\x08.v1.User\x12/\n\x0buser_groups\x18\x15 \x03(\x0b\x32\r.v1.UserGroupR\x0buser_groups\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\tPrincipal\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"g\n\nPrincipals\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.v1.Principal\x12\x1d\n\x06groups\x18\x02 \x03(\x0b\x32\r.v1.Principal\x12\x1c\n\x05roles\x18\x03 \x03(\x0b\x32\r.v1.Principal\"\x9e\x01\n\x15StrategyResourceEntry\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa5\x06\n\x11StrategyResources\x12>\n\x0bstrategy_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bstrategy_id\x12-\n\nnamespaces\x18\x02 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12+\n\x08services\x18\x03 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12?\n\rconfig_groups\x18\x04 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\rconfig_groups\x12;\n\x0broute_rules\x18\x05 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x0broute_rules\x12\x43\n\x0fratelimit_rules\x18\x06 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x0fratelimit_rules\x12M\n\x14\x63ircuitbreaker_rules\x18\x07 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x14\x63ircuitbreaker_rules\x12G\n\x11\x66\x61ultdetect_rules\x18\x08 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x11\x66\x61ultdetect_rules\x12\x39\n\nlane_rules\x18\t \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\nlane_rules\x12/\n\x05users\x18\x15 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x05users\x12;\n\x0buser_groups\x18\x16 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x0buser_groups\x12/\n\x05roles\x18\x17 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\x05roles\x12?\n\rauth_policies\x18\x18 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\rauth_policies\"W\n\x15StrategyResourceLabel\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\"\n\x0c\x63ompare_type\x18\x03 \x01(\tR\x0c\x63ompare_type\"\xf7\x05\n\x0c\x41uthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\"\n\nprincipals\x18\x03 \x01(\x0b\x32\x0e.v1.Principals\x12(\n\tresources\x18\x04 \x01(\x0b\x32\x15.v1.StrategyResources\x12\x1e\n\x06\x61\x63tion\x18\x05 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12\x46\n\x10\x64\x65\x66\x61ult_strategy\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x64\x65\x66\x61ult_strategy\x12\x30\n\x08metadata\x18\x0c \x03(\x0b\x32\x1e.v1.AuthStrategy.MetadataEntry\x12,\n\x06source\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tfunctions\x18\x0e \x03(\t\x12\x43\n\x0fresource_labels\x18\x0f \x03(\x0b\x32\x19.v1.StrategyResourceLabelR\x0fresource_labels\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x05\n\x12ModifyAuthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x0e\x61\x64\x64_principals\x18\x03 \x01(\x0b\x32\x0e.v1.PrincipalsR\x0e\x61\x64\x64_principals\x12<\n\x11remove_principals\x18\x04 \x01(\x0b\x32\x0e.v1.PrincipalsR\x11remove_principals\x12;\n\radd_resources\x18\x05 \x01(\x0b\x32\x15.v1.StrategyResourcesR\radd_resources\x12\x41\n\x10remove_resources\x18\x06 \x01(\x0b\x32\x15.v1.StrategyResourcesR\x10remove_resources\x12\x1e\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x08metadata\x18\x0c \x03(\x0b\x32$.v1.ModifyAuthStrategy.MetadataEntry\x12,\n\x06source\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tfunctions\x18\x0e \x03(\t\x12\x43\n\x0fresource_labels\x18\x0f \x03(\x0b\x32\x19.v1.StrategyResourceLabelR\x0fresource_labels\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*@\n\nAuthAction\x12\r\n\tONLY_READ\x10\x00\x12\x0e\n\nREAD_WRITE\x10\x01\x12\t\n\x05\x41LLOW\x10\n\x12\x08\n\x04\x44\x45NY\x10\x0b*\xd7\x01\n\x0cResourceType\x12\x0e\n\nNamespaces\x10\x00\x12\x0c\n\x08Services\x10\x01\x12\x10\n\x0c\x43onfigGroups\x10\x02\x12\x0e\n\nRouteRules\x10\x03\x12\x12\n\x0eRateLimitRules\x10\x04\x12\x17\n\x13\x43ircuitBreakerRules\x10\x05\x12\x14\n\x10\x46\x61ultDetectRules\x10\x06\x12\r\n\tLaneRules\x10\x07\x12\t\n\x05Users\x10\x14\x12\x0e\n\nUserGroups\x10\x15\x12\t\n\x05Roles\x10\x16\x12\x0f\n\x0bPolicyRules\x10\x17\x42\x82\x01\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/securityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/security'
  _globals['_LOGINREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_LOGINREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_LOGINRESPONSE_OPTIONSENTRY']._loaded_options = None
  _globals['_LOGINRESPONSE_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_USER_METADATAENTRY']._loaded_options = None
  _globals['_USER_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_USERGROUP_METADATAENTRY']._loaded_options = None
  _globals['_USERGROUP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MODIFYUSERGROUP_METADATAENTRY']._loaded_options = None
  _globals['_MODIFYUSERGROUP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ROLE_METADATAENTRY']._loaded_options = None
  _globals['_ROLE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_AUTHSTRATEGY_METADATAENTRY']._loaded_options = None
  _globals['_AUTHSTRATEGY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_MODIFYAUTHSTRATEGY_METADATAENTRY']._loaded_options = None
  _globals['_MODIFYAUTHSTRATEGY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_AUTHACTION']._serialized_start=6011
  _globals['_AUTHACTION']._serialized_end=6075
  _globals['_RESOURCETYPE']._serialized_start=6078
  _globals['_RESOURCETYPE']._serialized_end=6293
  _globals['_LOGINREQUEST']._serialized_start=51
  _globals['_LOGINREQUEST']._serialized_end=298
  _globals['_LOGINREQUEST_OPTIONSENTRY']._serialized_start=252
  _globals['_LOGINREQUEST_OPTIONSENTRY']._serialized_end=298
  _globals['_LOGINRESPONSE']._serialized_start=301
  _globals['_LOGINRESPONSE']._serialized_end=660
  _globals['_LOGINRESPONSE_OPTIONSENTRY']._serialized_start=252
  _globals['_LOGINRESPONSE_OPTIONSENTRY']._serialized_end=298
  _globals['_USER']._serialized_start=663
  _globals['_USER']._serialized_end=1399
  _globals['_USER_METADATAENTRY']._serialized_start=1352
  _globals['_USER_METADATAENTRY']._serialized_end=1399
  _globals['_MODIFYUSERPASSWORD']._serialized_start=1402
  _globals['_MODIFYUSERPASSWORD']._serialized_end=1596
  _globals['_USERGROUPRELATION']._serialized_start=1598
  _globals['_USERGROUPRELATION']._serialized_end=1700
  _globals['_USERGROUP']._serialized_start=1703
  _globals['_USERGROUP']._serialized_end=2353
  _globals['_USERGROUP_METADATAENTRY']._serialized_start=1352
  _globals['_USERGROUP_METADATAENTRY']._serialized_end=1399
  _globals['_MODIFYUSERGROUP']._serialized_start=2356
  _globals['_MODIFYUSERGROUP']._serialized_end=2953
  _globals['_MODIFYUSERGROUP_METADATAENTRY']._serialized_start=1352
  _globals['_MODIFYUSERGROUP_METADATAENTRY']._serialized_end=1399
  _globals['_ROLE']._serialized_start=2956
  _globals['_ROLE']._serialized_end=3267
  _globals['_ROLE_METADATAENTRY']._serialized_start=1352
  _globals['_ROLE_METADATAENTRY']._serialized_end=1399
  _globals['_PRINCIPAL']._serialized_start=3269
  _globals['_PRINCIPAL']._serialized_end=3366
  _globals['_PRINCIPALS']._serialized_start=3368
  _globals['_PRINCIPALS']._serialized_end=3471
  _globals['_STRATEGYRESOURCEENTRY']._serialized_start=3474
  _globals['_STRATEGYRESOURCEENTRY']._serialized_end=3632
  _globals['_STRATEGYRESOURCES']._serialized_start=3635
  _globals['_STRATEGYRESOURCES']._serialized_end=4440
  _globals['_STRATEGYRESOURCELABEL']._serialized_start=4442
  _globals['_STRATEGYRESOURCELABEL']._serialized_end=4529
  _globals['_AUTHSTRATEGY']._serialized_start=4532
  _globals['_AUTHSTRATEGY']._serialized_end=5291
  _globals['_AUTHSTRATEGY_METADATAENTRY']._serialized_start=1352
  _globals['_AUTHSTRATEGY_METADATAENTRY']._serialized_end=1399
  _globals['_MODIFYAUTHSTRATEGY']._serialized_start=5294
  _globals['_MODIFYAUTHSTRATEGY']._serialized_end=6009
  _globals['_MODIFYAUTHSTRATEGY_METADATAENTRY']._serialized_start=1352
  _globals['_MODIFYAUTHSTRATEGY_METADATAENTRY']._serialized_end=1399
# @@protoc_insertion_point(module_scope)
